@@ -13,9 +13,7 @@ const methods = [
   'move',
   'readJson',
   'readJSON',
-  'remove',
-  'writeJson',
-  'writeJSON'
+  'remove'
 ]
 
 describe('promise support', () => {
