@@ -1,46 +1,48 @@
+'use strict'
+
 // relevant: https://github.com/jprichardson/node-fs-extra/issues/89
 // come up with better file name
 
-var assert = require('assert')
-var fs = require('fs')
-var path = require('path')
-var os = require('os')
-var fse = require(process.cwd())
+const fs = require('fs')
+const os = require('os')
+const fse = require(process.cwd())
+const path = require('path')
+const assert = require('assert')
 
 /* global afterEach, beforeEach, describe, it */
 
-describe('copy / gh #89', function () {
-  var TEST_DIR = path.join(os.tmpdir(), 'fs-extra', 'copy-gh-89')
+describe('copy / gh #89', () => {
+  const TEST_DIR = path.join(os.tmpdir(), 'fs-extra', 'copy-gh-89')
 
-  beforeEach(function (done) {
+  beforeEach(done => {
     fse.emptyDir(TEST_DIR, done)
   })
 
-  afterEach(function (done) {
+  afterEach(done => {
     fse.remove(TEST_DIR, done)
   })
 
-  it('should...', function (done) {
-    var A = path.join(TEST_DIR, 'A')
-    var B = path.join(TEST_DIR, 'B')
+  it('should...', done => {
+    const A = path.join(TEST_DIR, 'A')
+    const B = path.join(TEST_DIR, 'B')
     fs.mkdirSync(A)
     fs.mkdirSync(B)
 
-    var one = path.join(A, 'one.txt')
-    var two = path.join(A, 'two.txt')
-    var three = path.join(B, 'three.txt')
-    var four = path.join(B, 'four.txt')
+    const one = path.join(A, 'one.txt')
+    const two = path.join(A, 'two.txt')
+    const three = path.join(B, 'three.txt')
+    const four = path.join(B, 'four.txt')
 
     fs.writeFileSync(one, '1')
     fs.writeFileSync(two, '2')
     fs.writeFileSync(three, '3')
     fs.writeFileSync(four, '4')
 
-    var C = path.join(TEST_DIR, 'C')
-    fse.copy(A, C, function (err) {
+    const C = path.join(TEST_DIR, 'C')
+    fse.copy(A, C, err => {
       if (err) return done(err)
 
-      fse.copy(B, C, function (err) {
+      fse.copy(B, C, err => {
         if (err) return done(err)
 
         assert(fs.existsSync(path.join(C, 'one.txt')))
