@@ -1,25 +1,25 @@
-var assert = require('assert')
-var util = require('util')
-var path = require('path')
-var os = require('os')
-var fs = require('graceful-fs')
-var CWD = process.cwd()
-var fse = require(CWD)
+'use strict'
 
-var _symlinkPaths = require('../symlink-paths')
-var symlinkPathsSync = _symlinkPaths.symlinkPathsSync
+const CWD = process.cwd()
 
-var ensureSymlink = fse.ensureSymlink
-var ensureSymlinkSync = fse.ensureSymlinkSync
+const fs = require('graceful-fs')
+const os = require('os')
+const fse = require(CWD)
+const path = require('path')
+const assert = require('assert')
+const _symlinkPaths = require('../symlink-paths')
+const symlinkPathsSync = _symlinkPaths.symlinkPathsSync
+const ensureSymlink = fse.ensureSymlink
+const ensureSymlinkSync = fse.ensureSymlinkSync
 
 /* global afterEach, beforeEach, describe, it, after, before */
 
-var TEST_DIR
+let TEST_DIR
 
-describe('fse-ensure-symlink', function () {
+describe('fse-ensure-symlink', () => {
   TEST_DIR = path.join(os.tmpdir(), 'fs-extra', 'ensure-symlink')
 
-  var tests = [
+  const tests = [
     // [[srcpath, dstpath], fs.symlink expect, fse.ensureSymlink expect]
     [['./foo.txt', './symlink.txt'], 'file-success', 'file-success'],
     [['../foo.txt', './empty-dir/symlink.txt'], 'file-success', 'file-success'],
@@ -56,12 +56,12 @@ describe('fse-ensure-symlink', function () {
     [[path.resolve(path.join(TEST_DIR, '../dir-foo/foo.txt')), './symlink.txt'], 'file-broken', 'file-error']
   ]
 
-  before(function () {
+  before(() => {
     fse.emptyDirSync(TEST_DIR)
     process.chdir(TEST_DIR)
   })
 
-  beforeEach(function () {
+  beforeEach(() => {
     fs.writeFileSync('./foo.txt', 'foo\n')
     fse.mkdirsSync('empty-dir')
     fse.mkdirsSync('dir-foo')
@@ -71,29 +71,26 @@ describe('fse-ensure-symlink', function () {
     fse.mkdirsSync('real-alpha/real-beta/real-gamma')
   })
 
-  afterEach(function (done) {
-    fse.emptyDir(TEST_DIR, done)
-  })
+  afterEach(done => fse.emptyDir(TEST_DIR, done))
 
-  after(function () {
+  after(() => {
     process.chdir(CWD)
     fse.removeSync(TEST_DIR)
   })
 
   function fileSuccess (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should create symlink file using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function (done) {
-      var callback = function (err) {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should create symlink file using src ${srcpath} and dst ${dstpath}`, done => {
+      const callback = err => {
         if (err) return done(err)
-        var relative = symlinkPathsSync(srcpath, dstpath)
-        var srcContent = fs.readFileSync(relative.toCwd, 'utf8')
-        var dstDir = path.dirname(dstpath)
-        var dstBasename = path.basename(dstpath)
-        var isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
-        var dstContent = fs.readFileSync(dstpath, 'utf8')
-        var dstDirContents = fs.readdirSync(dstDir)
+        const relative = symlinkPathsSync(srcpath, dstpath)
+        const srcContent = fs.readFileSync(relative.toCwd, 'utf8')
+        const dstDir = path.dirname(dstpath)
+        const dstBasename = path.basename(dstpath)
+        const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+        const dstContent = fs.readFileSync(dstpath, 'utf8')
+        const dstDirContents = fs.readdirSync(dstDir)
         assert.equal(isSymlink, true)
         assert.equal(srcContent, dstContent)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
@@ -105,21 +102,18 @@ describe('fse-ensure-symlink', function () {
   }
 
   function fileBroken (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should create broken symlink file using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function (done) {
-      var callback = function (err) {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should create broken symlink file using src ${srcpath} and dst ${dstpath}`, done => {
+      const callback = err => {
         if (err) return done(err)
-        var dstDir = path.dirname(dstpath)
-        var dstBasename = path.basename(dstpath)
-        var isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
-        var dstDirContents = fs.readdirSync(dstDir)
+        const dstDir = path.dirname(dstpath)
+        const dstBasename = path.basename(dstpath)
+        const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+        const dstDirContents = fs.readdirSync(dstDir)
         assert.equal(isSymlink, true)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
-        assert.throws(function () {
-          return fs.readFileSync(dstpath, 'utf8')
-        }, Error)
+        assert.throws(() => fs.readFileSync(dstpath, 'utf8'), Error)
         return done()
       }
       args.push(callback)
@@ -128,15 +122,14 @@ describe('fse-ensure-symlink', function () {
   }
 
   function fileError (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should return error when creating symlink file using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function (done) {
-      var dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
-      function callback (err) {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should return error when creating symlink file using src ${srcpath} and dst ${dstpath}`, done => {
+      const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
+      const callback = err => {
         assert.equal(err instanceof Error, true)
         // ensure that directories aren't created if there's an error
-        var dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
+        const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
         assert.equal(dstdirExistsBefore, dstdirExistsAfter)
         return done()
       }
@@ -146,14 +139,13 @@ describe('fse-ensure-symlink', function () {
   }
 
   function fileDestExists (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should do nothing using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function (done) {
-      var destinationContentBefore = fs.readFileSync(dstpath, 'utf8')
-      var callback = function (err) {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should do nothing using src ${srcpath} and dst ${dstpath}`, done => {
+      const destinationContentBefore = fs.readFileSync(dstpath, 'utf8')
+      const callback = err => {
         if (err) return done(err)
-        var destinationContentAfter = fs.readFileSync(dstpath, 'utf8')
+        const destinationContentAfter = fs.readFileSync(dstpath, 'utf8')
         assert.equal(destinationContentBefore, destinationContentAfter)
         return done()
       }
@@ -163,19 +155,18 @@ describe('fse-ensure-symlink', function () {
   }
 
   function dirSuccess (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should create symlink dir using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function (done) {
-      var callback = function (err) {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should create symlink dir using src ${srcpath} and dst ${dstpath}`, done => {
+      const callback = err => {
         if (err) return done(err)
-        var relative = symlinkPathsSync(srcpath, dstpath)
-        var srcContents = fs.readdirSync(relative.toCwd)
-        var dstDir = path.dirname(dstpath)
-        var dstBasename = path.basename(dstpath)
-        var isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
-        var dstContents = fs.readdirSync(dstpath)
-        var dstDirContents = fs.readdirSync(dstDir)
+        const relative = symlinkPathsSync(srcpath, dstpath)
+        const srcContents = fs.readdirSync(relative.toCwd)
+        const dstDir = path.dirname(dstpath)
+        const dstBasename = path.basename(dstpath)
+        const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+        const dstContents = fs.readdirSync(dstpath)
+        const dstDirContents = fs.readdirSync(dstDir)
         assert.equal(isSymlink, true)
         assert.deepEqual(srcContents, dstContents)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
@@ -187,21 +178,18 @@ describe('fse-ensure-symlink', function () {
   }
 
   function dirBroken (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should create broken symlink dir using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function (done) {
-      var callback = function (err) {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should create broken symlink dir using src ${srcpath} and dst ${dstpath}`, done => {
+      const callback = err => {
         if (err) return done(err)
-        var dstDir = path.dirname(dstpath)
-        var dstBasename = path.basename(dstpath)
-        var isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
-        var dstDirContents = fs.readdirSync(dstDir)
+        const dstDir = path.dirname(dstpath)
+        const dstBasename = path.basename(dstpath)
+        const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+        const dstDirContents = fs.readdirSync(dstDir)
         assert.equal(isSymlink, true)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
-        assert.throws(function () {
-          return fs.readdirSync(dstpath)
-        }, Error)
+        assert.throws(() => fs.readdirSync(dstpath), Error)
         return done()
       }
       args.push(callback)
@@ -210,15 +198,14 @@ describe('fse-ensure-symlink', function () {
   }
 
   function dirError (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should return error when creating symlink dir using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function (done) {
-      var dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
-      function callback (err) {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should return error when creating symlink dir using src ${srcpath} and dst ${dstpath}`, done => {
+      const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
+      const callback = err => {
         assert.equal(err instanceof Error, true)
         // ensure that directories aren't created if there's an error
-        var dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
+        const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
         assert.equal(dstdirExistsBefore, dstdirExistsAfter)
         return done()
       }
@@ -228,14 +215,13 @@ describe('fse-ensure-symlink', function () {
   }
 
   function dirDestExists (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should do nothing using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function (done) {
-      var destinationContentBefore = fs.readdirSync(dstpath)
-      var callback = function (err) {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should do nothing using src ${srcpath} and dst ${dstpath}`, done => {
+      const destinationContentBefore = fs.readdirSync(dstpath)
+      const callback = err => {
         if (err) return done(err)
-        var destinationContentAfter = fs.readdirSync(dstpath)
+        const destinationContentAfter = fs.readdirSync(dstpath)
         assert.deepEqual(destinationContentBefore, destinationContentAfter)
         return done()
       }
@@ -245,18 +231,17 @@ describe('fse-ensure-symlink', function () {
   }
 
   function fileSuccessSync (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should create symlink file using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function () {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should create symlink file using src ${srcpath} and dst ${dstpath}`, () => {
       fn.apply(null, args)
-      var relative = symlinkPathsSync(srcpath, dstpath)
-      var srcContent = fs.readFileSync(relative.toCwd, 'utf8')
-      var dstDir = path.dirname(dstpath)
-      var dstBasename = path.basename(dstpath)
-      var isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
-      var dstContent = fs.readFileSync(dstpath, 'utf8')
-      var dstDirContents = fs.readdirSync(dstDir)
+      const relative = symlinkPathsSync(srcpath, dstpath)
+      const srcContent = fs.readFileSync(relative.toCwd, 'utf8')
+      const dstDir = path.dirname(dstpath)
+      const dstBasename = path.basename(dstpath)
+      const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+      const dstContent = fs.readFileSync(dstpath, 'utf8')
+      const dstDirContents = fs.readdirSync(dstDir)
       assert.equal(isSymlink, true)
       assert.equal(srcContent, dstContent)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
@@ -264,66 +249,60 @@ describe('fse-ensure-symlink', function () {
   }
 
   function fileBrokenSync (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should create broken symlink file using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function () {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should create broken symlink file using src ${srcpath} and dst ${dstpath}`, () => {
       fn.apply(null, args)
-      var dstDir = path.dirname(dstpath)
-      var dstBasename = path.basename(dstpath)
-      var isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
-      var dstDirContents = fs.readdirSync(dstDir)
+      const dstDir = path.dirname(dstpath)
+      const dstBasename = path.basename(dstpath)
+      const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+      const dstDirContents = fs.readdirSync(dstDir)
       assert.equal(isSymlink, true)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
-      assert.throws(function () {
-        return fs.readFileSync(dstpath, 'utf8')
-      }, Error)
+      assert.throws(() => fs.readFileSync(dstpath, 'utf8'), Error)
     })
   }
 
   function fileErrorSync (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should throw error using` src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function () {
-      var dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
-      var err = null
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should throw error using src ${srcpath} and dst ${dstpath}`, () => {
+      const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
+      let err = null
       try {
         fn.apply(null, args)
       } catch (e) {
         err = e
       }
       assert.equal(err instanceof Error, true)
-      var dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
+      const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
       assert.equal(dstdirExistsBefore, dstdirExistsAfter)
     })
   }
 
   function fileDestExistsSync (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should do nothing using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function () {
-      var destinationContentBefore = fs.readFileSync(dstpath, 'utf8')
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should do nothing using src ${srcpath} and dst ${dstpath}`, () => {
+      const destinationContentBefore = fs.readFileSync(dstpath, 'utf8')
       fn.apply(null, args)
-      var destinationContentAfter = fs.readFileSync(dstpath, 'utf8')
+      const destinationContentAfter = fs.readFileSync(dstpath, 'utf8')
       assert.equal(destinationContentBefore, destinationContentAfter)
     })
   }
 
   function dirSuccessSync (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should create symlink dir using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function () {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should create symlink dir using src ${srcpath} and dst ${dstpath}`, () => {
       fn.apply(null, args)
-      var relative = symlinkPathsSync(srcpath, dstpath)
-      var srcContents = fs.readdirSync(relative.toCwd)
-      var dstDir = path.dirname(dstpath)
-      var dstBasename = path.basename(dstpath)
-      var isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
-      var dstContents = fs.readdirSync(dstpath)
-      var dstDirContents = fs.readdirSync(dstDir)
+      const relative = symlinkPathsSync(srcpath, dstpath)
+      const srcContents = fs.readdirSync(relative.toCwd)
+      const dstDir = path.dirname(dstpath)
+      const dstBasename = path.basename(dstpath)
+      const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+      const dstContents = fs.readdirSync(dstpath)
+      const dstDirContents = fs.readdirSync(dstDir)
       assert.equal(isSymlink, true)
       assert.deepEqual(srcContents, dstContents)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
@@ -331,59 +310,54 @@ describe('fse-ensure-symlink', function () {
   }
 
   function dirBrokenSync (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should create broken symlink dir using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function () {
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should create broken symlink dir using src ${srcpath} and dst ${dstpath}`, () => {
       fn.apply(null, args)
-      var dstDir = path.dirname(dstpath)
-      var dstBasename = path.basename(dstpath)
-      var isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
-      var dstDirContents = fs.readdirSync(dstDir)
+      const dstDir = path.dirname(dstpath)
+      const dstBasename = path.basename(dstpath)
+      const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+      const dstDirContents = fs.readdirSync(dstDir)
       assert.equal(isSymlink, true)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
-      assert.throws(function () {
-        return fs.readdirSync(dstpath)
-      }, Error)
+      assert.throws(() => fs.readdirSync(dstpath), Error)
     })
   }
 
   function dirErrorSync (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should throw error when creating symlink dir using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function () {
-      var dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
-      var err = null
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should throw error when creating symlink dir using src ${srcpath} and dst ${dstpath}`, () => {
+      const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
+      let err = null
       try {
         fn.apply(null, args)
       } catch (e) {
         err = e
       }
       assert.equal(err instanceof Error, true)
-      var dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
+      const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
       assert.equal(dstdirExistsBefore, dstdirExistsAfter)
     })
   }
 
   function dirDestExistsSync (args, fn) {
-    var srcpath = args[0]
-    var dstpath = args[1]
-    var should = util.format('should do nothing using src `%s` and dst `%s`', srcpath, dstpath)
-    it(should, function () {
-      var destinationContentBefore = fs.readdirSync(dstpath)
+    const srcpath = args[0]
+    const dstpath = args[1]
+    it(`should do nothing using src ${srcpath} and dst ${dstpath}`, () => {
+      const destinationContentBefore = fs.readdirSync(dstpath)
       fn.apply(null, args)
-      var destinationContentAfter = fs.readdirSync(dstpath)
+      const destinationContentAfter = fs.readdirSync(dstpath)
       assert.deepEqual(destinationContentBefore, destinationContentAfter)
     })
   }
 
-  describe('fs.symlink()', function () {
-    var fn = fs.symlink
-    tests.forEach(function (test) {
-      var args = test[0].slice(0)
-      var nativeBehavior = test[1]
-      // var newBehavior = test[2]
+  describe('fs.symlink()', () => {
+    const fn = fs.symlink
+    tests.forEach(test => {
+      const args = test[0].slice(0)
+      const nativeBehavior = test[1]
+      // const newBehavior = test[2]
       if (nativeBehavior === 'file-success') fileSuccess(args, fn)
       if (nativeBehavior === 'file-broken') fileBroken(args, fn)
       if (nativeBehavior === 'file-error') fileError(args, fn)
@@ -396,12 +370,12 @@ describe('fse-ensure-symlink', function () {
     })
   })
 
-  describe('ensureSymlink()', function () {
-    var fn = ensureSymlink
-    tests.forEach(function (test) {
-      var args = test[0]
-      // var nativeBehavior = test[1]
-      var newBehavior = test[2]
+  describe('ensureSymlink()', () => {
+    const fn = ensureSymlink
+    tests.forEach(test => {
+      const args = test[0]
+      // const nativeBehavior = test[1]
+      const newBehavior = test[2]
       if (newBehavior === 'file-success') fileSuccess(args, fn)
       if (newBehavior === 'file-broken') fileBroken(args, fn)
       if (newBehavior === 'file-error') fileError(args, fn)
@@ -413,12 +387,35 @@ describe('fse-ensure-symlink', function () {
     })
   })
 
-  describe('fs.symlinkSync()', function () {
-    var fn = fs.symlinkSync
-    tests.forEach(function (test) {
-      var args = test[0].slice(0)
-      var nativeBehavior = test[1]
-      // var newBehavior = test[2]
+  describe('ensureSymlink() promise support', () => {
+    tests.filter(test => test[2] === 'file-success').forEach(test => {
+      const args = test[0]
+      const srcpath = args[0]
+      const dstpath = args[1]
+      it(`should create symlink file using src ${srcpath} and dst ${dstpath}`, () => {
+        return ensureSymlink(srcpath, dstpath)
+          .then(() => {
+            const relative = symlinkPathsSync(srcpath, dstpath)
+            const srcContent = fs.readFileSync(relative.toCwd, 'utf8')
+            const dstDir = path.dirname(dstpath)
+            const dstBasename = path.basename(dstpath)
+            const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
+            const dstContent = fs.readFileSync(dstpath, 'utf8')
+            const dstDirContents = fs.readdirSync(dstDir)
+            assert.equal(isSymlink, true)
+            assert.equal(srcContent, dstContent)
+            assert(dstDirContents.indexOf(dstBasename) >= 0)
+          })
+      })
+    })
+  })
+
+  describe('fs.symlinkSync()', () => {
+    const fn = fs.symlinkSync
+    tests.forEach(test => {
+      const args = test[0].slice(0)
+      const nativeBehavior = test[1]
+      // const newBehavior = test[2]
       if (nativeBehavior === 'file-success') fileSuccessSync(args, fn)
       if (nativeBehavior === 'file-broken') fileBrokenSync(args, fn)
       if (nativeBehavior === 'file-error') fileErrorSync(args, fn)
@@ -431,12 +428,12 @@ describe('fse-ensure-symlink', function () {
     })
   })
 
-  describe('ensureSymlinkSync()', function () {
-    var fn = ensureSymlinkSync
-    tests.forEach(function (test) {
-      var args = test[0]
-      // var nativeBehavior = test[1]
-      var newBehavior = test[2]
+  describe('ensureSymlinkSync()', () => {
+    const fn = ensureSymlinkSync
+    tests.forEach(test => {
+      const args = test[0]
+      // const nativeBehavior = test[1]
+      const newBehavior = test[2]
       if (newBehavior === 'file-success') fileSuccessSync(args, fn)
       if (newBehavior === 'file-broken') fileBrokenSync(args, fn)
       if (newBehavior === 'file-error') fileErrorSync(args, fn)
